@@ -1,7 +1,7 @@
 package Net::Stripe::Invoice;
-$Net::Stripe::Invoice::VERSION = '0.40_004'; # TRIAL
+$Net::Stripe::Invoice::VERSION = '0.40_005'; # TRIAL
 
-$Net::Stripe::Invoice::VERSION = '0.40004';use Moose;
+$Net::Stripe::Invoice::VERSION = '0.40005';use Moose;
 use Kavorka;
 extends 'Net::Stripe::Resource';
 
@@ -16,6 +16,7 @@ has 'attempted'     => ( is => 'ro', isa => 'Maybe[Bool|Object]', required => 1
 has 'closed'        => ( is => 'ro', isa => 'Maybe[Bool|Object]', trigger => \&_closed_change_detector);
 has 'auto_advance'  => ( is => 'ro', isa => 'Maybe[Bool]');
 has 'created'       => ( is => 'ro', isa => 'Maybe[Int]' );
+has 'customer'      => ( is => 'ro', isa => 'Maybe[Str]', required => 1 );
 has 'date'          => ( is => 'ro', isa => 'Maybe[Str]' );
 has 'lines'         => ( is => 'ro', isa => 'Net::Stripe::List', required => 1 );
 has 'paid'          => ( is => 'ro', isa => 'Maybe[Bool|Object]', required => 1 );
@@ -61,7 +62,7 @@ Net::Stripe::Invoice - represent an Invoice object from Stripe
 
 =head1 VERSION
 
-version 0.40_004
+version 0.40_005
 
 =head1 ATTRIBUTES
 
@@ -119,6 +120,14 @@ Reader: created
 
 Type: Maybe[Int]
 
+=head2 customer
+
+Reader: customer
+
+Type: Maybe[Str]
+
+This attribute is required.
+
 =head2 date
 
 Reader: date
