@@ -1,7 +1,7 @@
 package Net::Stripe::Resource;
-$Net::Stripe::Resource::VERSION = '0.40_004'; # TRIAL
+$Net::Stripe::Resource::VERSION = '0.40_005'; # TRIAL
 
-$Net::Stripe::Resource::VERSION = '0.40004';# ABSTRACT: represent a Resource object from Stripe
+$Net::Stripe::Resource::VERSION = '0.40005';# ABSTRACT: represent a Resource object from Stripe
 
 use Moose;
 use Kavorka;
@@ -99,6 +99,11 @@ method fields_for($for) {
     return $thingy->form_fields if ref($thingy) =~ m/^Net::Stripe::/;
     return form_fields_for_hashref( $for, $thingy ) if ref( $thingy ) eq 'HASH';
     return form_fields_for_arrayref( $for, $thingy ) if ref( $thingy ) eq 'ARRAY';
+
+    my $token_id_type = Moose::Util::TypeConstraints::find_type_constraint( 'StripeTokenId' );
+    return form_fields_for_hashref( $for, { token => $thingy } )
+        if $self->isa( 'Net::Stripe::PaymentMethod' ) && $for eq 'card' && $token_id_type->check( $thingy );
+
     return ( $for => $self->get_form_field_value( $for ) );
 }
 
@@ -129,7 +134,7 @@ Net::Stripe::Resource - represent a Resource object from Stripe
 
 =head1 VERSION
 
-version 0.40_004
+version 0.40_005
 
 =head1 ATTRIBUTES
 
