@@ -1,7 +1,7 @@
 package Net::Stripe::TypeConstraints;
-$Net::Stripe::TypeConstraints::VERSION = '0.40_004'; # TRIAL
+$Net::Stripe::TypeConstraints::VERSION = '0.40_005'; # TRIAL
 
-$Net::Stripe::TypeConstraints::VERSION = '0.40004';use strict;
+$Net::Stripe::TypeConstraints::VERSION = '0.40005';use strict;
 use Moose::Util::TypeConstraints qw/subtype as where message enum/;
 
 # ABSTRACT: Custom Moose TypeConstraints for Net::Stripe object attributes and parameters
@@ -91,6 +91,34 @@ subtype 'StripeAPIVersion',
         );
     };
 
+subtype 'StripePaymentMethodId',
+    as 'Str',
+    where {
+        /^pm_.+/
+    },
+    message {
+        sprintf( "Value '%s' must be a payment method id string of the form pm_.+", $_ );
+    };
+
+subtype 'StripePaymentIntentId',
+    as 'Str',
+    where {
+        /^pi_.+/
+    },
+    message {
+        sprintf( "Value '%s' must be a payment intent id string of the form pi_.+", $_ );
+    };
+
+enum StripePaymentMethodType => [qw/ card sepia_debit ideal /];
+
+enum StripeCaptureMethod => [qw/ automatic manual /];
+
+enum StripeConfirmationMethod => [qw/ automatic manual /];
+
+enum StripeCancellationReason => [qw/ duplicate fraudulent requested_by_customer abandoned /];
+
+enum StripeSetupFutureUsage => [qw/ on_session off_session /];
+
 1;
 
 __END__
@@ -103,7 +131,7 @@ Net::Stripe::TypeConstraints - Custom Moose TypeConstraints for Net::Stripe obje
 
 =head1 VERSION
 
-version 0.40_004
+version 0.40_005
 
 =head1 AUTHORS
 
